function [b,bint,r,rint,stats] = myreg3(y,X,alpha)
% extracted by SPE on 12/17/99 from 
% myreg2.m 
%REGRESS Multiple linear regression using least squares.
%   b = REGRESS(y,X) returns the vector of regression coefficients, B.
%   Given the linear model: y = Xb,
%   (X is an nxp matrix, y is the nx1 vector of observations.)
%   [B,BINT,R,RINT,STATS] = REGRESS(y,X,alpha) uses the input, ALPHA
%   to calculate 100(1 - ALPHA) confidence intervals for B and the
%   residual vector, R, in BINT and RINT respectively.
%   The vector STATS contains the R-square statistic along with the F
%   and p values for the regression.

%   References:
%      [1] Samprit Chatterjee and Ali S. Hadi, "Influential Observations,
%      High Leverage Points, and Outliers in Linear Regression",
%      Statistical Science 1986 Vol. 1 No. 3 pp. 379-416.
%      [2] N. Draper and H. Smith, "Applied Regression Analysis, Second
%      Edition", Wiley, 1981.

%   B.A. Jones 3-04-93
%   Copyright (c) 1993-97 by The MathWorks, Inc.
%   $Revision: 2.5 $  $Date: 1997/04/08 15:13:03 $

if  nargin < 2,
    error('REGRESS requires at least two input arguments.');
end

if nargin == 2,
    alpha = 0.05;
end

% Check that matrix (X) and left hand side (y) have compatible dimensions
[n,p] = size(X);
[n1,collhs] = size(y);
if n ~= n1,
    error('The number of rows in Y must equal the number of rows in X.');
end

if collhs ~= 1,
    error('Y must be a vector, not a matrix');
end

% Find the least squares solution.
[Q, R]=qr(X,0);
b = R\(Q'*y);

yhat = X*b;                     % Predicted responses at each data point.
r = y-yhat;                     % Residuals.

bint=0;
rint=0;

% Calculate R-squared.
if nargout==5,
   RSS = norm(yhat-mean(y))^2;  % Residual sum of squares.
   TSS = norm(y-mean(y))^2;     % Total sum of squares.
   r2 = RSS/TSS;                % R-square statistic.
   stats = r2;
end




